@@ -1,13 +1,16 @@
-# Copyright 2013 tsuru-circus authors. All rights reserved.
+# Copyright 2014 tsuru-circus authors. All rights reserved.
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
 import os
 import re
 
+from socket import gethostname
+
+import requests
+
 from circus.plugins import CircusPlugin
 from circus.client import CircusClient
-
 from honcho.procfile import Procfile
 from zmq.eventloop import ioloop
 
@@ -88,7 +91,9 @@ class ApprcWatcher(CircusPlugin):
         if "PYTHONPATH" in values and "PYTHONPATH" not in envs:
             del values["PYTHONPATH"]
         if values != current:
+            self.call("stop", name=name)
             self.call("set", name=name, options={"env": values})
+            self.cast("start", name=name)
 
     def cmds(self):
         return self.call("status")["statuses"].keys()
@@ -163,12 +168,12 @@ class ProcfileWatcher(CircusPlugin):
         })
 
     def remove_watcher(self, name):
-        self.call("rm", name=name)
+        self.cast("rm", name=name)
 
     def change_cmd(self, name, cmd):
         env = self.load_envs()
         cmd = replace_args(cmd, **env)
-        self.call("set", name=name, options={"cmd": cmd})
+        self.cast("set", name=name, options={"cmd": cmd})
 
     def commands(self, procfile):
         cmds = self.call("status")["statuses"]
@@ -199,3 +204,45 @@ class ProcfileWatcher(CircusPlugin):
 
             for name, cmd in to_change.items():
                 self.change_cmd(name=name, cmd=procfile.commands[name])
+
+
+class StatusReporter(CircusPlugin):
+    name = "status_reporter"
+
+    def __init__(self, *args, **config):
+        super(StatusReporter, self).__init__(*args, **config)
+        self.loop_rate = config.get("loop_rate", 60)
+        self.apprc = config.get("apprc", "/home/application/apprc")
+        self.hostname = gethostname()
+        self.period = ioloop.PeriodicCallback(self.report,
+                                              self.loop_rate * 1000,
+                                              self.loop)
+
+    def handle_init(self):
+        self.period.start()
+
+    def handle_stop(self):
+        self.period.stop()
+
+    def handle_recv(self, data):
+        pass
+
+    def report(self):
+        cmds = self.call("status")["statuses"]
+        if "tsuru-hooks" in cmds:
+            del cmds["tsuru-hooks"]
+        status = "started"
+        for cmd_name, cmd_status in cmds.iteritems():
+            if cmd_name.startswith("plugin:"):
+                continue
+            if cmd_status != "active":
+                status = "error"
+                break
+        envs = common.load_envs(self.apprc)
+        url_data = {"host": envs.get("TSURU_HOST"),
+                    "appname": envs.get("TSURU_APPNAME"),
+                    "unitname": self.hostname}
+        url = "{host}/apps/{appname}/units/{unitname}"
+        token = envs.get("TSURU_APP_TOKEN")
+        requests.post(url.format(**url_data), data={"status": status},
+                      headers={"Authorization": "bearer " + token})
